@@ -1,4 +1,4 @@
-# ClamTk, copyright (C) 2004-2012 Dave M
+# ClamTk, copyright (C) 2004-2013 Dave M
 #
 # This file is part of ClamTk (http://clamtk.sourceforge.net).
 #
@@ -23,7 +23,7 @@ use Locale::gettext;
 
 sub get_TK_version {
     # Stick with %.2f format - 4.50 vice 4.5
-    return '4.41';
+    return '4.45';
 }
 
 sub get_path {
@@ -268,7 +268,7 @@ sub get_sig_info {
 
     # warn "using >$daily_path< for definitions.\n";
     # warn "I'm missing daily.{cld,cvd} and/or main.{cld,cvd}.\n"
-    #    unless ( $daily_path && $main_path );
+    #   unless ( $daily_path && $main_path );
 
     # $INFO_DATE = Date of signatures
     # $INFO_DAILY = # of 'daily' signatures (not part of main.{cld,cvd})
@@ -312,18 +312,22 @@ sub get_sig_info {
     my ( $cvd_day, $cvd_mon, $cvd_year );
 
     # Check for .cld
-    if ( -e "$daily_path/daily.cld" ) {
-        if ( open( my $cld_db, '-|', "$sigtool -i $daily_path/daily.cld" ) ) {
-            while (<$cld_db>) {
-                if (/Build time:\s(\d+\s\w+\s\d{4})/i) {
-                    ( $cld_day, $cld_mon, $cld_year ) = split( /\s+/, $1 );
-                }
-                if (/Signatures:\s(\d+)/) {
-                    $INFO_DAILY = $1;
+    if ($daily_path) {
+        if ( -e "$daily_path/daily.cld" ) {
+            if (open( my $cld_db, '-|', "$sigtool -i $daily_path/daily.cld" )
+                ) {
+                while (<$cld_db>) {
+                    if (/Build time:\s(\d+\s\w+\s\d{4})/i) {
+                        ( $cld_day, $cld_mon, $cld_year ) =
+                            split( /\s+/, $1 );
+                    }
+                    if (/Signatures:\s(\d+)/) {
+                        $INFO_DAILY = $1;
+                    }
                 }
+                #close($cld_db)
+                #    or warn "Couldn't close $daily_path (cld): $!\n";
             }
-            #close($cld_db)
-            #    or warn "Couldn't close $daily_path (cld): $!\n";
         }
     }
     if ( !$cld_day ) {
@@ -333,18 +337,22 @@ sub get_sig_info {
     }
 
     # Check for .cvd
-    if ( -e "$daily_path/daily.cvd" ) {
-        if ( open( my $cvd_db, '-|', "$sigtool -i $daily_path/daily.cvd" ) ) {
-            while (<$cvd_db>) {
-                if (/Build time:\s(\d+\s\w+\s\d{4})/i) {
-                    ( $cvd_day, $cvd_mon, $cvd_year ) = split( /\s+/, $1 );
-                }
-                if (/Signatures:\s(\d+)/) {
-                    $INFO_DAILY = $1;
+    if ($daily_path) {
+        if ( -e "$daily_path/daily.cvd" ) {
+            if (open( my $cvd_db, '-|', "$sigtool -i $daily_path/daily.cvd" )
+                ) {
+                while (<$cvd_db>) {
+                    if (/Build time:\s(\d+\s\w+\s\d{4})/i) {
+                        ( $cvd_day, $cvd_mon, $cvd_year ) =
+                            split( /\s+/, $1 );
+                    }
+                    if (/Signatures:\s(\d+)/) {
+                        $INFO_DAILY = $1;
+                    }
                 }
+                #close($cvd_db)
+                #    or warn "Couldn't close $daily_path (cvd): $!\n";
             }
-            #close($cvd_db)
-            #    or warn "Couldn't close $daily_path (cvd): $!\n";
         }
     }
     if ( !$cvd_day ) {
