@@ -1,4 +1,4 @@
-# ClamTk, copyright (C) 2004-2012 Dave M
+# ClamTk, copyright (C) 2004-2013 Dave M
 #
 # This file is part of ClamTk (http://clamtk.sourceforge.net).
 #
@@ -46,7 +46,6 @@ my $SCAN;              # Scan handle; must be global for stop button
 my $scan_pid;          # Pid of scan handle; must be global for stop button
 my $stopped = 1;       # Program is stopped if 1, running if 0
 my $found;             # Stores info about possibly infected files
-my $gui_tb;            # Easy buttons bar
 my $start_time;        # For use with Elapsed time
 my $scan_frame;        # Holds the progressbar, files scanned, etc.
 my $drop_frame;        # For the drag and drop stuff
@@ -125,13 +124,13 @@ sub start_gui {
 
         ### These fall under "Scan", although it's still called FileMenu. ###
         # Scan a single file
-        [   'Scan_File',        undef,
+        [   'Scan_File',        'gtk-file',
             gettext('A _File'), '<control>F',
             undef, 	sub { ClamTk::GUI->getfile('file') },
 	    FALSE
         ],
         # Scan home directory, but do not descend
-        [   'Quick_Home', 		undef,
+        [   'Quick_Home', 		'gtk-home',
             gettext('Home (_Quick)'), 	'<control>Q',
             undef, 	sub { ClamTk::GUI->getfile('home') },
 	    FALSE
@@ -143,7 +142,7 @@ sub start_gui {
 	    FALSE
         ],
         # Scan a single directory
-        [   'Scan_Directory', 		undef,
+        [   'Scan_Directory', 		'gtk-directory',
             gettext('A _Directory'), 	'<control>D',
             undef,	sub { ClamTk::GUI->getfile('dir') },
 	    FALSE
@@ -155,13 +154,13 @@ sub start_gui {
 	    FALSE
         ],
         # Scan a device - relies upon udev and /proc/mounts
-        [   'Scan_Device', 		undef,
+        [   'Scan_Device', 		'gtk-cdrom',
             gettext('A Device'), 	'<control>J', undef,	
 			sub { ClamTk::Device->look_for_device($window->get_position) },
 	    FALSE
         ],
         # Quit
-        [   'Exit',           undef,
+        [   'Exit',           'gtk-quit',
             gettext('E_xit'), '<control>X',
             undef,	sub { Gtk2->main_quit },
 	    FALSE
@@ -169,19 +168,19 @@ sub start_gui {
 
         ### These fall under View ###
         # Show dialog of recorded scans
-        [   'ManageHistories', 		undef,
-            gettext('Manage _Histories'), "<control>H",
+        [   'ManageHistory', 		'gtk-edit',
+            gettext('_History'), "<control>H",
             undef, 	sub { history('delete') },
             FALSE
         ],
         # Show last scan info (date of scan and last infected)
-        [   'LastScanInfo', 		undef,
+        [   'LastScanInfo', 		'gtk-info',
             gettext('_Last Scan Information'), "<control>L",
             undef, 	\&last_scan,
             FALSE
         ],
         # Closes the scan bar, zeroes out everything
-        [   'ClearOutput',                undef,
+        [   'ClearOutput',                'gtk-clear',
             gettext('Clear _Output'),     '<control>O',
             undef,	\&clear_output,
             FALSE
@@ -201,7 +200,7 @@ sub start_gui {
 	    FALSE
         ],
         # Delete quarantined objects
-        [   'Empty', 			undef,
+        [   'Empty', 			'gtk-delete',
             gettext('_Empty Quarantine Folder'), '<control>E',
             undef,	\&del_quarantined,
 	    FALSE
@@ -209,13 +208,13 @@ sub start_gui {
 
         ### These fall under Help ###
         # Dialog box for Help, to update signatures, check for GUI updates.
-        [   'UpdateSig', 			undef,
+        [   'UpdateSig', 			'gtk-network',
             gettext('_Check for updates'), 	'<control>U',
 	    undef,	sub { ClamTk::Update->update_dialog($window->get_position) },
 	    FALSE
         ],
         # Standard About dialog
-        [   'About',                          undef,
+        [   'About',                          'gtk-about',
             gettext("_About"),                '<control>A',
             undef,	\&about,
 	    FALSE
@@ -236,7 +235,7 @@ sub start_gui {
 	    FALSE
         ],
         # Huge preferences window
-        [   'Preferences',          undef,
+        [   'Preferences',          'gtk-preferences',
             gettext('Preferences'), '<control>P',
             undef,	\&preferences,
 	    FALSE
@@ -264,7 +263,7 @@ sub start_gui {
           <menuitem action='Exit'/>
          </menu>
           <menu action='ViewMenu'>
-          <menuitem action='ManageHistories'/>
+          <menuitem action='ManageHistory'/>
           <menuitem action='LastScanInfo'/>
           <menuitem action='ClearOutput'/>
          </menu>
@@ -311,8 +310,10 @@ sub start_gui {
     $vbox->pack_start( $gui_frame, FALSE, FALSE, 0 );
     $gui_frame->set_shadow_type('none');
 
-    my $gui_box = Gtk2::VBox->new( TRUE, 5 );
-    $gui_frame->add($gui_box);
+    my $ebox = Gtk2::EventBox->new;
+    my $gui_box = Gtk2::VBox->new( TRUE, 10 );
+    $ebox->add($gui_box);
+    $gui_frame->add($ebox);
 
     # Now that Gnome has decided to not show the images
     # in buttons by default, the regular buttons looked pretty stupid.
@@ -320,7 +321,7 @@ sub start_gui {
     # to a toolbar and using those buttons.  Nice try, Gnome.
     # The toolbar ($gui_tb) is global so we can change its style
     # from the Preferences dialog.
-    $gui_tb = Gtk2::Toolbar->new;
+    my $gui_tb = Gtk2::Toolbar->new;
     $gui_tb->set_style('both');
     $gui_tb->set_show_arrow(FALSE);
 
@@ -338,7 +339,7 @@ sub start_gui {
     # Button for histories
     my $hist_img = Gtk2::ToolButton->new_from_stock('gtk-edit');
     $hist_img->set_expand(TRUE);
-    $hist_img->set_label( gettext('Histories') );
+    $hist_img->set_label( gettext('History') );
     $hist_img->signal_connect( clicked => sub { history('delete') } );
     $tt->set_tip( $hist_img, gettext('View your previous scans') );
     $gui_tb->insert( $hist_img, -1 );
@@ -383,7 +384,7 @@ sub start_gui {
     my $gui_version_text = Gtk2::Label->new( ClamTk::App->get_TK_version() );
     $status_gui_img =
         Gtk2::Image->new_from_stock( 'gtk-yes', 'small-toolbar' );
-    $tt->set_tip( $status_gui_img, gettext('Current') );
+    $tt->set_tip( $status_gui_img, gettext('The GUI version is up-to-date') );
     $status_gui_box->pack_start( $status_gui_img,   TRUE, TRUE, 0 );
     $status_gui_box->pack_start( $gui_text,         TRUE, TRUE, 0 );
     $status_gui_box->pack_start( $gui_version_text, TRUE, TRUE, 0 );
@@ -394,7 +395,8 @@ sub start_gui {
     my $defs_text = Gtk2::Label->new( gettext('Antivirus definitions') );
     $defs_version_text = Gtk2::Label->new( gettext('Unknown') );
     $defs_gui_img = Gtk2::Image->new_from_stock( 'gtk-yes', 'small-toolbar' );
-    $tt->set_tip( $defs_gui_img, gettext('Current') );
+    $tt->set_tip( $defs_gui_img,
+        gettext('The antivirus definitions are up-to-date') );
     $defs_gui_box->pack_start( $defs_gui_img,      TRUE, TRUE, 0 );
     $defs_gui_box->pack_start( $defs_text,         TRUE, TRUE, 0 );
     $defs_gui_box->pack_start( $defs_version_text, TRUE, TRUE, 0 );
@@ -405,8 +407,9 @@ sub start_gui {
     my $engine_text = Gtk2::Label->new( gettext('Antivirus engine') );
     $engine_version_text = Gtk2::Label->new( gettext('Unknown') );
     $engine_gui_img =
-        Gtk2::Image->new_from_stock( 'gtk-info', 'small-toolbar' );
-    $tt->set_tip( $engine_gui_img, gettext('Version') );
+        Gtk2::Image->new_from_stock( 'gtk-yes', 'small-toolbar' );
+    $tt->set_tip( $engine_gui_img,
+        gettext('Indicates the version of the antivirus engine') );
     $engine_gui_box->pack_start( $engine_gui_img,      TRUE, TRUE, 0 );
     $engine_gui_box->pack_start( $engine_text,         TRUE, TRUE, 0 );
     $engine_gui_box->pack_start( $engine_version_text, TRUE, TRUE, 0 );
@@ -662,7 +665,8 @@ sub update_status_frame {
         $tt->set_tip( $status_gui_img, gettext('Unable to check') );
     } elsif ( $ret == 1 || $ret == 3 ) {
         $status_gui_img->set_from_stock( 'gtk-yes', 'small-toolbar' );
-        $tt->set_tip( $status_gui_img, gettext('Current') );
+        $tt->set_tip( $status_gui_img,
+            gettext('The GUI version is up-to-date') );
     } else {
         $status_gui_img->set_from_stock( 'gtk-no', 'small-toolbar' );
         $tt->set_tip( $status_gui_img,
@@ -702,11 +706,12 @@ sub set_sig_status {
         $defs_gui_img->set_from_stock( 'gtk-no', 'small-toolbar' );
         $defs_version_text->set_text( gettext('Outdated') );
         $tt->set_tip( $defs_gui_img,
-            gettext('Your antivirus signatures are out-of-date') );
+            gettext('The antivirus signatures are out-of-date') );
     } else {
         $defs_gui_img->set_from_stock( 'gtk-yes', 'small-toolbar' );
         $defs_version_text->set_text( gettext('Current') );
-        $tt->set_tip( $defs_gui_img, gettext('Current') );
+        $tt->set_tip( $defs_gui_img,
+            gettext('The antivirus definitions are up-to-date') );
     }
     $tt->set_tip( $defs_version_text,
         $sig_date ? $sig_date : gettext('Unknown') );
@@ -724,7 +729,8 @@ sub set_tk_status {
         $tt->set_tip( $status_gui_img, gettext('Unable to check') );
     } elsif ( $ret == 1 || $ret == 3 ) {
         $status_gui_img->set_from_stock( 'gtk-yes', 'small-toolbar' );
-        $tt->set_tip( $status_gui_img, gettext('Current') );
+        $tt->set_tip( $status_gui_img,
+            gettext('The GUI version is up-to-date') );
     } else {
         $status_gui_img->set_from_stock( 'gtk-no', 'small-toolbar' );
         $tt->set_tip( $status_gui_img,
@@ -795,7 +801,8 @@ sub getfile {
     # Once we figure out KDE's process, we'll include that too.
     if ( !ClamTk::Prefs->get_preference('Mounted') ) {
         # This returned a '0', so filter the results
-        for my $m (qw(.gvfs smb4k)) {
+        for my $m ( 'smb4k', "/run/user/$ENV{USER}/gvfs", "$ENV{HOME}/.gvfs" )
+        {
             $directive .= " --exclude-dir=$m";
         }
     }
@@ -1592,7 +1599,7 @@ sub history {
     if ( scalar(@h_files) > 1 ) {
         @h_files = history_sort(@h_files);
     }
-    my $new_win = Gtk2::Dialog->new( gettext('Scanning Histories'),
+    my $new_win = Gtk2::Dialog->new( gettext('Scanning History'),
         $window, 'destroy-with-parent' );
     $new_win->set_default_size( 400, 200 );
 
@@ -1607,7 +1614,7 @@ sub history {
     $s_win->set_policy( 'automatic', 'automatic' );
     $new_vbox->pack_start( $s_win, TRUE, TRUE, 0 );
 
-    $new_hlist = Gtk2::SimpleList->new( gettext('Histories') => 'text' );
+    $new_hlist = Gtk2::SimpleList->new( gettext('History') => 'text' );
     $s_win->add($new_hlist);
     $new_hlist->set_headers_clickable(TRUE);
     $new_hlist->get_column(0)->signal_connect(
@@ -1648,6 +1655,12 @@ sub history {
             view_box( $new_win->get_position );
         } );
 
+    my $del_single = Gtk2::ToolButton->new_from_stock('gtk-delete');
+    $del_single->set_is_important(TRUE);
+    $new_bar->insert( $del_single, -1 );
+    $del_single->signal_connect(
+        clicked => sub { history_del_single( \@h_files ) } );
+
     my $n_sep = Gtk2::SeparatorToolItem->new;
     $n_sep->set_draw(FALSE);
     $n_sep->set_expand(TRUE);
@@ -1658,12 +1671,6 @@ sub history {
     $new_bar->insert( $pos_quit, -1 );
     $pos_quit->signal_connect( clicked => sub { $new_win->destroy } );
 
-    my $del_single = Gtk2::ToolButton->new_from_stock('gtk-delete');
-    $del_single->set_is_important(TRUE);
-    $new_bar->insert( $del_single, -1 );
-    $del_single->signal_connect(
-        clicked => sub { history_del_single( \@h_files ) } );
-
     for my $opt (@h_files) {
         $opt =~ s/\.log//;
         push @{ $new_hlist->{data} }, basename($opt);
@@ -1804,9 +1811,11 @@ sub preferences {
     $nb->set( 'enable-popup' => TRUE );
 
     my $scan_table = Gtk2::Table->new( 4, 1, TRUE );
-    $nb->insert_page( $scan_table, gettext('Scanning Preferences'), 0 );
+    $nb->insert_page( $scan_table, gettext('Scanning'), 0 );
 
-    my $hidden_box = Gtk2::CheckButton->new_with_label(
+    my $hidden_box =
+        Gtk2::CheckButton->new_with_label( gettext('Scan hidden files') );
+    $tt->set_tip( $hidden_box,
         gettext('Scan files beginning with a dot (.*)') );
     $hidden_box->set_active(TRUE) if ( $prefs{ScanHidden} );
     $scan_table->attach_defaults( $hidden_box, 0, 1, 0, 1 );
@@ -1818,6 +1827,8 @@ sub preferences {
     $hidden_box->can_focus(FALSE);
 
     my $recur_box = Gtk2::CheckButton->new_with_label(
+        gettext('Scan directories recursively') );
+    $tt->set_tip( $recur_box,
         gettext('Scan all files and directories within a directory') );
     $recur_box->set_active(TRUE) if ( $prefs{Recursive} );
     $scan_table->attach_defaults( $recur_box, 0, 1, 1, 2 );
@@ -1829,7 +1840,10 @@ sub preferences {
     $recur_box->can_focus(FALSE);
 
     my $deep_box = Gtk2::CheckButton->new_with_label(
-        gettext('Enable extra scan settings') );
+        gettext('Scan for Potentially Unwanted Applications (PUA)') );
+    $tt->set_tip( $deep_box,
+        gettext('Detect packed binaries, password recovery tools, and more')
+        );
     $deep_box->set_active(TRUE) if ( $prefs{Thorough} );
     $scan_table->attach_defaults( $deep_box, 0, 1, 2, 3 );
     $deep_box->signal_connect(
@@ -1841,6 +1855,8 @@ sub preferences {
 
     my $size_box = Gtk2::CheckButton->new_with_label(
         gettext('Scan files larger than 20 MB') );
+    $tt->set_tip( $size_box,
+        gettext('Scan large files which are typically not examined') );
     $size_box->set_active(TRUE) if ( $prefs{SizeLimit} );
     $scan_table->attach_defaults( $size_box, 0, 1, 3, 4 );
     $size_box->signal_connect(
@@ -1854,7 +1870,11 @@ sub preferences {
         # We're sprintf-ing this so that %s can
         # expand to KIO or whatever KDE uses and it
         # won't require a translation change
-        sprintf gettext('Scan samba-related directories %s'), "(gvfs, smb4k)"
+        gettext('Scan samba-related directories') );
+    $tt->set_tip(
+        $mounted_box,
+        sprintf gettext('Scan samba-related directories %s'),
+        "(gvfs, smb4k)"
         );
     $mounted_box->set_active(TRUE) if ( $prefs{Mounted} );
     $scan_table->attach_defaults( $mounted_box, 0, 1, 4, 5 );
@@ -1866,7 +1886,7 @@ sub preferences {
     $mounted_box->can_focus(FALSE);
 
     my $startup_table = Gtk2::Table->new( 3, 1, TRUE );
-    $nb->insert_page( $startup_table, gettext('Startup Preferences'), 1 );
+    $nb->insert_page( $startup_table, gettext('Startup'), 1 );
 
     my $gui_box =
         Gtk2::CheckButton->new_with_label( gettext('Check for GUI updates') );
@@ -1954,6 +1974,20 @@ sub preferences {
 
     my $del_btn = Gtk2::Button->new_from_stock('gtk-delete');
     $ex_bar->add($del_btn);
+    $del_btn->set_sensitive(FALSE);
+
+    $ex_slist->signal_connect(
+        'cursor-changed' => sub {
+            my @line = $ex_slist->get_selected_indices;
+
+            my $deref = $line[0];
+            if ( $ex_slist->{data}[$deref][0] ) {
+                $del_btn->set_sensitive(TRUE);
+            } else {
+                $del_btn->set_sensitive(FALSE);
+            }
+        } );
+
     $del_btn->signal_connect(
         clicked => sub {
             my @sel = $ex_slist->get_selected_indices;
@@ -1972,10 +2006,12 @@ sub preferences {
 
             # remove it from the GUI
             splice @{ $ex_slist->{data} }, $deref, 1;
+            @sel = $ex_slist->get_selected_indices;
+            $del_btn->set_sensitive(FALSE) if ( !@sel );
         } );
 
     my $big_proxy = Gtk2::VBox->new( FALSE, 5 );
-    $nb->insert_page( $big_proxy, gettext('Proxy settings'), 3 );
+    $nb->insert_page( $big_proxy, gettext('Proxy'), 3 );
 
     my $no_proxy_box = Gtk2::VBox->new;
     $big_proxy->pack_start( $no_proxy_box, FALSE, FALSE, 0 );
@@ -2202,36 +2238,6 @@ sub preferences {
     $sep->set_expand(TRUE);
     $scroll->insert( $sep, -1 );
 
-    # We don't need to set_label for these buttons because
-    # they're stock and the right phrasing.
-    my $prev_btn = Gtk2::ToolButton->new_from_stock('gtk-go-back');
-    $prev_btn->set_is_important(TRUE);
-    $scroll->insert( $prev_btn, -1 );
-    $prev_btn->signal_connect(
-        clicked => sub {
-            if ( $nb->get_current_page == 0 ) {
-                $nb->set_current_page( $nb->get_n_pages - 1 );
-            } else {
-                $nb->prev_page;
-            }
-        } );
-
-    $scroll->insert( Gtk2::SeparatorToolItem->new, -1 );
-
-    my $next_btn = Gtk2::ToolButton->new_from_stock('gtk-go-forward');
-    $next_btn->set_is_important(TRUE);
-    $scroll->insert( $next_btn, -1 );
-    $next_btn->signal_connect(
-        clicked => sub {
-            if ( $nb->get_current_page == ( $nb->get_n_pages - 1 ) ) {
-                $nb->set_current_page(0);
-            } else {
-                $nb->next_page;
-            }
-        } );
-
-    $scroll->insert( Gtk2::SeparatorToolItem->new, -1 );
-
     my $close_btn = Gtk2::ToolButton->new_from_stock('gtk-close');
     $close_btn->set_is_important(TRUE);
     $scroll->insert( $close_btn, -1 );
@@ -2331,7 +2337,7 @@ sub get_md5 {
 sub about {
     my $about = Gtk2::AboutDialog->new;
     $about->set_program_name('ClamTk');
-    $about->set_authors("Dave M, 2004-2012\ndave.nerd <at> gmail.com");
+    $about->set_authors("Dave M, 2004-2013\ndave.nerd <at> gmail.com");
     $about->set_version( ClamTk::App->get_TK_version() );
     my $contributors = 'Please see http://clamtk.sf.net/credits.html';
     $about->set_translator_credits($contributors);
