@@ -1,4 +1,4 @@
-# ClamTk, copyright (C) 2004-2012 Dave M
+# ClamTk, copyright (C) 2004-2013 Dave M
 #
 # This file is part of ClamTk (http://clamtk.sourceforge.net).
 #
@@ -15,7 +15,7 @@ package ClamTk::Schedule;
 # scheduling, so we have call crontab as a system command.
 
 # use strict;
-# use warnings FATAL => 'all';
+# use warnings;
 $| = 1;
 
 use POSIX 'locale_h';
@@ -378,6 +378,16 @@ sub apply_scan {
         }
     }
 
+    # By default, we ignore .gvfs directories.
+    # Check the user preference as well:
+    if ( !ClamTk::Prefs->get_preference('Mounted') ) {
+        # This returned a '0', so filter the results
+        for my $m ( 'smb4k', "/run/user/$ENV{USER}/gvfs", "$ENV{HOME}/.gvfs" )
+        {
+            $full_cmd .= " --exclude-dir=$m";
+        }
+    }
+
     # Ignore mail directories until we can parse stuff
     for my $not_parse (
         qw| .thunderbird	.mozilla-thunderbird
