@@ -1,4 +1,4 @@
-# ClamTk, copyright (C) 2004-2012 Dave M
+# ClamTk, copyright (C) 2004-2013 Dave M
 #
 # This file is part of ClamTk (http://clamtk.sourceforge.net).
 #
@@ -16,9 +16,10 @@ package ClamTk::Submit;
 # use strict;
 # use warnings FATAL => 'all';
 $| = 1;
+use encoding 'utf8';
 
 use LWP::UserAgent;
-use Encode 'from_to', 'decode';
+use Encode 'encode';
 use Date::Calc 'Delta_Days';
 use File::Basename 'basename';
 
@@ -56,7 +57,7 @@ sub analysis {
     my ( undef, $x, $y ) = @_;
     $sub_window = Gtk2::Dialog->new();
     $sub_window->signal_connect( close => sub { $sub_window->destroy } );
-    $sub_window->set_title( change( gettext('Submit a file for analysis') ) );
+    $sub_window->set_title( gettext('Submit a file for analysis') );
     if ( -e '/usr/share/pixmaps/clamtk.png' ) {
         $sub_window->set_default_icon_from_file(
             '/usr/share/pixmaps/clamtk.png');
@@ -79,7 +80,7 @@ sub analysis {
 
     $name_desc = Gtk2::Label->new;
     $table->attach_defaults( $name_desc, 0, 1, 0, 1 );
-    $name_string = change( gettext('Name') );
+    $name_string = gettext('Name');
     $name_desc->set_markup($name_string);
     my $n_filled_field = Gtk2::Label->new;
     $n_filled_field->set_markup($required_field);
@@ -97,7 +98,7 @@ sub analysis {
 
     $email_desc = Gtk2::Label->new;
     $table->attach_defaults( $email_desc, 0, 1, 1, 2 );
-    $email_string = change( gettext('Email') );
+    $email_string = gettext('Email');
     $email_desc->set_markup($email_string);
     my $e_filled_field = Gtk2::Label->new;
     $e_filled_field->set_markup($required_field);
@@ -115,11 +116,11 @@ sub analysis {
         } );
 
     # The default string for the area holding the filename
-    $file_string = change( gettext('No file selected') );
+    $file_string = gettext('No file selected');
     # This shades it a little
     $long_string = "<span foreground='#CCCCCC'>$file_string</span>";
 
-    my $file_text = change( gettext('Select File') );
+    my $file_text = gettext('Select File');
     $file_btn = Gtk2::Button->new($file_text);
     $table->attach_defaults( $file_btn, 0, 1, 2, 3 );
     $file_btn->signal_connect(
@@ -153,22 +154,19 @@ sub analysis {
     # The file can be categorized as either
     # new malware (undetected) or a false positive.
     # New malware is the default option.
-    my $sampleis_text =
-        Gtk2::Label->new( change( gettext('The attached file is') ) );
+    my $sampleis_text = Gtk2::Label->new( gettext('The attached file is') );
     $table->attach_defaults( $sampleis_text, 0, 1, 3, 4 );
     my $bb = Gtk2::HButtonBox->new();
     $bb->set_layout('end');
     $table->attach_defaults( $bb, 1, 3, 3, 4 );
-    $new_btn =
-        Gtk2::RadioButton->new( undef, change( gettext('New malware') ) );
+    $new_btn = Gtk2::RadioButton->new( undef, gettext('New malware') );
     my $false_pos =
-        Gtk2::RadioButton->new( $new_btn,
-        change( gettext('A false positive') ) );
+        Gtk2::RadioButton->new( $new_btn, gettext('A false positive') );
     $bb->add($new_btn);
     $bb->add($false_pos);
 
     # Optional description of the file being uploaded
-    my $desc_text  = change( gettext('Description') );
+    my $desc_text  = gettext('Description');
     my $desc_label = Gtk2::Label->new($desc_text);
     $table->attach_defaults( $desc_label, 0, 1, 4, 5 );
     $desc_entry = Gtk2::Entry->new_with_max_length(50);
@@ -229,8 +227,7 @@ sub analysis {
     my $amount = get_amount();
     if ( $amount >= 2 ) {
         my $message =
-            change(
-            gettext('Please do not submit more than two files per day.') );
+            gettext('Please do not submit more than two files per day.');
         my $dialog =
             Gtk2::MessageDialog->new_with_markup( $sub_window,
             [qw(modal destroy-with-parent)],
@@ -251,7 +248,7 @@ sub clear {
 
 sub select_file {
     my $picker = Gtk2::FileChooserDialog->new(
-        change( gettext('Select File') ), $sub_window, 'open',
+        gettext('Select File'), $sub_window, 'open',
         'gtk-cancel' => 'cancel',
         'gtk-ok'     => 'ok',
         );
@@ -273,15 +270,12 @@ sub double_check {
         field_check() || return;
     }
 
-    my $message =
-        change( gettext('You are about to submit a file for analysis.') );
+    my $message = gettext('You are about to submit a file for analysis.');
     $message .= "\n\n";
-    $message
-        .= change( gettext('Press OK to continue, or Cancel to go back.') );
+    $message .= gettext('Press OK to continue, or Cancel to go back.');
 
-    my $dialog =
-        Gtk2::MessageDialog->new( $sub_window, 'destroy-with-parent', 'info',
-        'ok-cancel', $message );
+    my $dialog = Gtk2::MessageDialog->new( $sub_window, 'destroy-with-parent',
+        'info', 'ok-cancel', $message );
     if ( 'ok' eq $dialog->run() ) {
         $dialog->destroy();
         submit();
@@ -318,34 +312,29 @@ sub submit {
     # URL we're posting to
     $url .= ( $sampleis eq 'virus' ) ? 'sendmalware.cgi' : 'sendfp.cgi';
 
-    # Apparently this is necessary
-    from_to( $sendername,  'ISO-8859-1', 'UTF-8' );
-    from_to( $email,       'ISO-8859-1', 'UTF-8' );
-    from_to( $description, 'ISO-8859-1', 'UTF-8' );
-    from_to( $sampleis,    'ISO-8859-1', 'UTF-8' );
-    from_to( $chosen,      'ISO-8859-1', 'UTF-8' );
-
-    $statusbar->set_text( change( gettext('Please wait...') ) );
+    $statusbar->set_text( gettext('Please wait...') );
     Gtk2->main_iteration while ( Gtk2->events_pending );
 
     my $req = $ua->post(
         $url,
-        Content_Type => 'form-data',
+        Content_Type => 'multipart/form-data;charset=utf-8',
         Content      => [
             action       => 'submit',
-            sendername   => $sendername,
-            email        => $email,
+            sendername   => encode( 'utf8', $sendername ),
+            email        => encode( 'utf8', $email ),
             'Send virus' => 'submit',
-            name         => $description,
-            sampleis     => $sampleis,
-            file         => [$chosen],
+            name         => encode( 'utf8', $description ),
+            sampleis     => encode( 'utf8', $sampleis ),
+            file         => [ encode( 'utf8', $chosen ) ],
             ],
             );
 
+    # Generic success statement
     if (   $req->is_success
         && $req->decoded_content =~ /has been successfully sent/ ) {
         increase_amount();
         finish('success');
+        # This means a file was submitted to be recognized, but already is
     } elsif ( $req->decoded_content =~ /already recognized/ ) {
         my $as = '';
         if ( $req->decoded_content =~ /as (.*?) . Be/ ) {
@@ -353,6 +342,11 @@ sub submit {
         }
         increase_amount();
         finish( 'known', $as );
+        # This means a file was submitted as a false positive, but is
+        # not currently detected
+    } elsif ( $req->decoded_content =~ /This file is not detected by/ ) {
+        increase_amount();
+        finish('falsefalse');
     } else {
         finish('failed');
     }
@@ -366,21 +360,20 @@ sub finish {
 
     my $message = "\n";
     if ( $status eq 'success' ) {
-        $message = change( gettext('The submission was successful!') );
+        $message = gettext('The submission was successful!');
     } elsif ( $status eq 'known' ) {
-        $message =
-            change( gettext('The file you submitted is already recognized') );
+        $message = gettext('The file you submitted is already recognized');
         $message .= "\n";
         if ($known) {
             $message .= "($known)";
         } else {
             $message .= '.';
         }
+    } elsif ( $status eq 'falsefalse' ) {
+        $message = gettext('This file is not currently a false positive');
     } else {
-        $message = change(
-            gettext(
-                'Unable to complete the submission. Please try again later.')
-                );
+        $message = gettext(
+            'Unable to complete the submission. Please try again later.');
     }
     $statusbar->set_text($message);
     clear();
@@ -400,15 +393,11 @@ sub create_view {
     $sw->set_border_width(5);
 
     my @text = (
-        change( gettext('With this form, you can:') ),
-        change( gettext('Report new viruses which are not detected') ),
-        change(
-            gettext('Report clean files which are incorrectly detected')
-            ),
-        change(
-            gettext('Please do not submit more than two files per day.')
-            ),
-            );
+        gettext('With this form, you can:'),
+        gettext('Report new viruses which are not detected'),
+        gettext('Report clean files which are incorrectly detected'),
+        gettext('Please do not submit more than two files per day.'),
+        );
 
     my $line = "\n";
     $line .= $text[0];
@@ -429,7 +418,7 @@ sub create_view {
     $buffer->insert_with_tags_by_name( $iter, $line, 'mono' );
     $buffer->insert_with_tags_by_name( $iter, '* ',  'red' );
     $buffer->insert_with_tags_by_name( $iter,
-        change( gettext('Indicates a required field') ), 'mono' );
+        gettext('Indicates a required field'), 'mono' );
 
     $sw->add($view);
     return $sw;
@@ -588,10 +577,6 @@ sub get_todays_date {
     return ( $year, $month, $day );
 }
 
-sub change {
-    return decode( 'utf-8', $_[0] );
-}
-
 sub valid_email {
     my $check = shift;
 #<<< Perltidy needs to ignore this.
