@@ -1,4 +1,4 @@
-# ClamTk, copyright (C) 2004-2012 Dave M
+# ClamTk, copyright (C) 2004-2013 Dave M
 #
 # This file is part of ClamTk (http://clamtk.sourceforge.net).
 #
@@ -36,7 +36,7 @@ sub update_dialog {
     my ( undef, $x, $y ) = @_;
     $win = Gtk2::Dialog->new();
     $win->signal_connect( destroy => sub { $win->destroy; } );
-    $win->set_title( gettext('Virus Scanner') );
+    $win->set_title( gettext('Check for updates') );
     $win->set_default_size( 625, 130 );
     $win->move( $x, $y );
 
@@ -106,34 +106,6 @@ sub update_dialog {
     $win->vbox->pack_start( $choicebar, FALSE, FALSE, 0 );
     $win->vbox->set_focus_child($choicebar);
 
-    my $u_sep = Gtk2::SeparatorToolItem->new;
-    $u_sep->set_draw(FALSE);
-    $u_sep->set_expand(TRUE);
-    $choicebar->insert( $u_sep, -1 );
-
-    # Check for updates button
-    $go_btn = Gtk2::ToolButton->new_from_stock('gtk-network');
-    $go_btn->set_is_important(TRUE);
-    $go_btn->set_expand(FALSE);
-    $go_btn->set_label( gettext('Check for updates') );
-    $go_btn->signal_connect( clicked => \&decision );
-    $choicebar->insert( $go_btn, -1 );
-
-    $choicebar->insert( Gtk2::SeparatorToolItem->new, -1 );
-
-    # Close window button
-    $close_btn = Gtk2::ToolButton->new_from_stock('gtk-close');
-    $close_btn->set_is_important(TRUE);
-    $close_btn->set_expand(FALSE);
-    $close_btn->signal_connect(
-        clicked => sub {
-            $update_win->destroy;
-            $win->destroy;
-        } );
-    $choicebar->insert( $close_btn, -1 );
-
-    $choicebar->insert( Gtk2::SeparatorToolItem->new, -1 );
-
     # Cancel button
     $cancel_btn = Gtk2::ToolButton->new_from_stock('gtk-cancel');
     $cancel_btn->set_is_important(TRUE);
@@ -152,6 +124,30 @@ sub update_dialog {
     $choicebar->insert( $cancel_btn, -1 );
     $cancel_btn->set_sensitive(FALSE);
 
+    # Check for updates button
+    $go_btn = Gtk2::ToolButton->new_from_stock('gtk-network');
+    $go_btn->set_is_important(TRUE);
+    $go_btn->set_expand(FALSE);
+    $go_btn->set_label( gettext('Check for updates') );
+    $go_btn->signal_connect( clicked => \&decision );
+    $choicebar->insert( $go_btn, -1 );
+
+    my $u_sep = Gtk2::SeparatorToolItem->new;
+    $u_sep->set_draw(FALSE);
+    $u_sep->set_expand(TRUE);
+    $choicebar->insert( $u_sep, -1 );
+
+    # Close window button
+    $close_btn = Gtk2::ToolButton->new_from_stock('gtk-close');
+    $close_btn->set_is_important(TRUE);
+    $close_btn->set_expand(FALSE);
+    $close_btn->signal_connect(
+        clicked => sub {
+            $update_win->destroy;
+            $win->destroy;
+        } );
+    $choicebar->insert( $close_btn, -1 );
+
     # Warn the user not to do things as root.
     if ( $> == 0 ) {
         my $warning_btn =
@@ -595,6 +591,9 @@ sub save {
                     copy( "$dir_list/main.cvd", "$paths/main.cvd" );
                     $m = 1;
                 }
+                if ( -e "$dir_list/bytecode.cld" ) {
+                    copy( "$dir_list/bytecode.cld", "$paths/bytecode.cld" );
+                }
                 last if ( $d && $m );
             }
         }
